@@ -68,6 +68,7 @@ ArchiveFormats: tuple[str, ...] = (
     'deb',
     'dms',
     'flac',
+    'freearc',
     'gzip',
     'iso',
     'lrzip',
@@ -126,6 +127,7 @@ ArchiveMimetypes: dict[str, str] = {
     'application/x-cpio': 'cpio',
     'application/x-debian-package': 'deb',
     'application/x-dms': 'dms',
+    'application/x-freearc': 'freearc',
     'application/x-iso9660-image': 'iso',
     'application/x-lz4': 'lz4',
     'application/x-lzop': 'lzop',
@@ -156,6 +158,7 @@ ArchiveMimetypes: dict[str, str] = {
 # List of programs supporting the given archive format and command.
 # If command is None, the program supports all commands (list, extract, ...)
 # Programs starting with "py_" are Python modules.
+# {<format>: {<command>: (<program>,...)}
 ArchivePrograms: dict[str, dict[str | None, tuple[str, ...]]] = {
     '7z': {
         None: ('7z', '7za', '7zr', '7zz', '7zzs'),
@@ -185,12 +188,19 @@ ArchivePrograms: dict[str, dict[str | None, tuple[str, ...]]] = {
     'ar': {
         None: ('ar',),
     },
+    # Note:
+    # ".arc" files can be in ARC or FREEARC format
+    # https://en.wikipedia.org/wiki/ARC_(file_format)
+    # https://en.wikipedia.org/wiki/FreeArc
     'arc': {
         None: ('arc',),
         'extract': ('nomarch',),
         'test': ('nomarch',),
         'list': ('nomarch',),
     },
+    'freearc': {
+        None: ('arc',),
+    },
     'arj': {
         None: ('arj',),
         'extract': ('7z', '7zz', '7zzs'),
@@ -622,6 +632,11 @@ def find_archive_program(
                     continue
                 if format == 'compress' and not util.p7zip_supports_compress(program):
                     continue
+            elif program == 'arc':
+                # arc program supports either ARC or FREEARC formats
+                # find out if it's the one we need
+                if util.get_arc_format(exe) != format:
+                    continue
             if not check_program_compression(
                 command, program, exe, compression, verbosity=verbosity
             ):
@@ -1084,24 +1099,37 @@ def _repack_archive(
         return
     tmpdir = fileutil.tmpdir()
     try:
-        kwargs = dict(verbosity=verbosity, outdir=tmpdir, password=password)
         same_format = format1 == format2 and compression1 and compression2
         if same_format:
             # only decompress since the format is the same
-            kwargs['format'] = compression1
-        path = _extract_archive(archive1, **kwargs)
+            format = compression1
+        else:
+            format = None
+        path = _extract_archive(
+            archive1,
+            verbosity=verbosity,
+            outdir=tmpdir,
+            password=password,
+            format=format,
+        )
         archive = os.path.abspath(archive2)
         files = tuple(os.listdir(path))
         olddir = os.getcwd()
         os.chdir(path)
         try:
-            kwargs = dict(
-                verbosity=verbosity, interactive=interactive, password=password
-            )
             if same_format:
                 # only compress since the format is the same
-                kwargs['format'] = compression2
-            _create_archive(archive, files, **kwargs)
+                format = compression2
+            else:
+                format = None
+            _create_archive(
+                archive,
+                files,
+                verbosity=verbosity,
+                interactive=interactive,
+                password=password,
+                format=format,
+            )
         finally:
             os.chdir(olddir)
     finally:
