@@ -1,5 +1,4 @@
-# -*- coding: utf-8 -*-
-# Copyright (C) 2010-2015 Bastian Kleineidam
+# Copyright (C) 2010-2023 Bastian Kleineidam
 #
 # This program is free software: you can redistribute it and/or modify
 # it under the terms of the GNU General Public License as published by
@@ -14,9 +13,13 @@
 # You should have received a copy of the GNU General Public License
 # along with this program.  If not, see <http://www.gnu.org/licenses/>.
 """Archive commands for the unace program."""
+
 import os
 
-def extract_ace(archive, compression, cmd, verbosity, interactive, outdir, password=None):
+
+def extract_ace(
+    archive, compression, cmd, verbosity, interactive, outdir, password=None
+):
     """Extract an ACE archive."""
     cmdlist = [cmd, 'x']
     if not outdir.endswith(os.sep):
@@ -26,6 +29,7 @@ def extract_ace(archive, compression, cmd, verbosity, interactive, outdir, passw
     cmdlist.extend([archive, outdir])
     return cmdlist
 
+
 def list_ace(archive, compression, cmd, verbosity, interactive, password=None):
     """List an ACE archive."""
     cmdlist = [cmd]
@@ -38,6 +42,7 @@ def list_ace(archive, compression, cmd, verbosity, interactive, password=None):
     cmdlist.append(archive)
     return cmdlist
 
+
 def test_ace(archive, compression, cmd, verbosity, interactive, password=None):
     """Test an ACE archive."""
     cmdlist = [cmd, 't']
