@@ -1,4 +1,3 @@
-# -*- coding: utf-8 -*-
 # Copyright (C) 2023 Bastian Kleineidam
 #
 # This program is free software: you can redistribute it and/or modify
@@ -15,14 +14,16 @@
 # along with this program.  If not, see <http://www.gnu.org/licenses/>.
 """Archive commands for the unar program."""
 
+
 def _extract(archive, compression, cmd, verbosity, interactive, outdir, password=None):
     """Extract an archive."""
     cmdlist = [cmd, '-o', outdir]
     if password:
-        cmdlist.append('-p', password)
+        cmdlist.extend(['-p', password])
     cmdlist.append(archive)
     return cmdlist
 
+
 extract_rar = _extract
 extract_zip = _extract
 extract_7z = _extract
