@@ -1,5 +1,4 @@
-# -*- coding: utf-8 -*-
-# Copyright (C) 2010-2015 Bastian Kleineidam
+# Copyright (C) 2010-2023 Bastian Kleineidam
 #
 # This program is free software: you can redistribute it and/or modify
 # it under the terms of the GNU General Public License as published by
@@ -13,15 +12,20 @@
 #
 # You should have received a copy of the GNU General Public License
 # along with this program.  If not, see <http://www.gnu.org/licenses/>.
+"""Test the clzip program"""
+
 from . import ArchiveTest, Content
 from .. import needs_program
 
-class TestClzip (ArchiveTest):
+
+class TestClzip(ArchiveTest):
+    """Test class for the clzip program"""
 
     program = 'clzip'
 
     @needs_program(program)
     def test_clzip(self):
+        """Test, extract and create an LZIP archive."""
         self.archive_test('t.txt.lz')
         self.archive_extract('t.txt.lz', check=Content.Singlefile)
         self.archive_create('t.txt.lz', check=Content.Singlefile)
@@ -29,6 +33,6 @@ class TestClzip (ArchiveTest):
     @needs_program('file')
     @needs_program(program)
     def test_clzip_file(self):
+        """Test and extract a renamed LZIP archive."""
         self.archive_test('t.txt.lz.foo')
         self.archive_extract('t.txt.lz.foo', check=Content.Singlefile)
-
