@@ -1,5 +1,4 @@
-# -*- coding: utf-8 -*-
-# Copyright (C) 2013-2015 Bastian Kleineidam
+# Copyright (C) 2013-2023 Bastian Kleineidam
 #
 # This program is free software: you can redistribute it and/or modify
 # it under the terms of the GNU General Public License as published by
@@ -13,10 +12,14 @@
 #
 # You should have received a copy of the GNU General Public License
 # along with this program.  If not, see <http://www.gnu.org/licenses/>.
+"""Test the genisoimage program"""
+
 from . import ArchiveTest
 from .. import needs_program
 
+
 class TestGenisoimage(ArchiveTest):
+    """Test class for the genisoimage program"""
 
     program = 'genisoimage'
 
@@ -24,4 +27,5 @@ class TestGenisoimage(ArchiveTest):
     @needs_program('7z')
     @needs_program(program)
     def test_genisoimage(self):
+        """Create an ISO archive."""
         self.archive_create('t.iso')
