@@ -1,5 +1,4 @@
-# -*- coding: utf-8 -*-
-# Copyright (C) 2010-2012 Bastian Kleineidam
+# Copyright (C) 2010-2023 Bastian Kleineidam
 #
 # This program is free software: you can redistribute it and/or modify
 # it under the terms of the GNU General Public License as published by
@@ -13,14 +12,18 @@
 #
 # You should have received a copy of the GNU General Public License
 # along with this program.  If not, see <http://www.gnu.org/licenses/>.
+"""Test the lhasa program"""
+
 from . import ArchiveTest
 from .. import needs_program
 
-class TestLhasa (ArchiveTest):
+
+class TestLhasa(ArchiveTest):
+    """Test class for the lhasa program"""
 
     program = 'lhasa'
 
     @needs_program(program)
     def test_lhasa(self):
+        """Extract an LHA archive."""
         self.archive_extract('t.lha')
-
