@@ -1,5 +1,4 @@
-# -*- coding: utf-8 -*-
-# Copyright (C) 2010-2015 Bastian Kleineidam
+# Copyright (C) 2010-2023 Bastian Kleineidam
 #
 # This program is free software: you can redistribute it and/or modify
 # it under the terms of the GNU General Public License as published by
@@ -13,20 +12,25 @@
 #
 # You should have received a copy of the GNU General Public License
 # along with this program.  If not, see <http://www.gnu.org/licenses/>.
+"""Test the python gzip module"""
+
 from . import ArchiveTest, Content
 from .. import needs_program
 
-class TestPygzip (ArchiveTest):
+
+class TestPygzip(ArchiveTest):
+    """Test class for the python gzip module"""
 
     program = 'py_gzip'
 
     @needs_program('gzip')
-    def test_py_gzip (self):
+    def test_py_gzip(self):
+        """Extract and create GZIP archives."""
         self.archive_extract('t.txt.gz', check=Content.Singlefile)
         # gzip is used to test the created archive
         self.archive_create('t.txt.gz', check=Content.Singlefile)
 
     @needs_program('file')
-    def test_py_gzip_file (self):
+    def test_py_gzip_file(self):
+        """Extract renamed GZIP archives."""
         self.archive_extract('t.txt.gz.foo', check=Content.Singlefile)
-
