@@ -1,5 +1,4 @@
-# -*- coding: utf-8 -*-
-# Copyright (C) 2010-2012 Bastian Kleineidam
+# Copyright (C) 2010-2023 Bastian Kleineidam
 #
 # This program is free software: you can redistribute it and/or modify
 # it under the terms of the GNU General Public License as published by
@@ -13,24 +12,29 @@
 #
 # You should have received a copy of the GNU General Public License
 # along with this program.  If not, see <http://www.gnu.org/licenses/>.
+"""Test the unalz program"""
+
 from . import ArchiveTest
 from .. import needs_program
 
-class TestUnalz (ArchiveTest):
+
+class TestUnalz(ArchiveTest):
+    """Test class for the unalz program"""
 
     program = 'unalz'
 
     @needs_program(program)
     def test_unalz(self):
+        """Test, list and extract ALZ archives."""
         self.archive_test('t.alz')
         self.archive_list('t.alz')
         self.archive_extract('t.alz')
 
     # file(1) does not recognize .alz files
-    #@needs_program('file')
-    #@needs_program(program)
-    #def test_unalz_file(self):
+    # @needs_program('file')
+    # @needs_program(program)
+    # def test_unalz_file(self):
+    #    """Test, list and extract renamed ALZ archives."""
     #    self.archive_test('t.alz.foo')
     #    self.archive_list('t.alz.foo')
     #    self.archive_extract('t.alz.foo')
-
