@@ -28,6 +28,7 @@ class TestMime(unittest.TestCase):
         """Test that file has given mime and encoding as determined by
         given function.
         """
+        self.assertTrue(os.path.isfile(filename), f"archive {filename!r} is not a file")
         file_mime, file_encoding = func(filename)
         fail_msg = "%s for archive `%s' should be %s, but was %s. Info: %s"
         if isinstance(mime, tuple):
@@ -73,7 +74,7 @@ class TestMime(unittest.TestCase):
         self.mime_test_file("t.arj.foo", "application/x-arj")
         self.mime_test_file("t.txt.bz2", "application/x-bzip2")
         self.mime_test_file("t.txt.bz2.foo", "application/x-bzip2")
-        # fails on ubuntu-latest github ci
+        # fails on macos-15 github ci
         # self.mime_test_file("t.txt.bz3", "application/x-bzip3")
         # self.mime_test_file("t.txt.bz3.foo", "application/x-bzip3")
         self.mime_test_file("t.cab", "application/vnd.ms-cab-compressed")
@@ -102,7 +103,7 @@ class TestMime(unittest.TestCase):
         self.mime_test_file("t.tar.foo", "application/x-tar")
         self.mime_test_file("t.cbt", "application/x-tar")
         self.mime_test_file("t.cbt.foo", "application/x-tar")
-        # fails on ubuntu-latest github ci
+        # fails on macos-15 and windows-2025 github ci
         # self.mime_test_file("t.tar.lz", "application/x-tar", "lzip")
         self.mime_test_file("t.tar.bz2", "application/x-tar", "bzip2")
         self.mime_test_file("t.tbz2", "application/x-tar", "bzip2")
@@ -142,6 +143,8 @@ class TestMime(unittest.TestCase):
         self.mime_test_file("t.alz.foo", "application/x-alzip")
         self.mime_test_file("t.arc", "application/x-arc")
         self.mime_test_file("t.arc.foo", "application/x-arc")
+        self.mime_test_file("t.freearc.arc", "application/x-freearc")
+        self.mime_test_file("t.freearc.arc.foo", "application/x-freearc")
         self.mime_test_file("t.txt.lz4", "application/x-lz4")
         self.mime_test_file("t.txt.lz4.foo", "application/x-lz4")
         self.mime_test_file("t.txt.lrz", "application/x-lrzip")
@@ -234,19 +237,15 @@ class TestMime(unittest.TestCase):
         self.mime_test_mimedb("t .7z", "application/x-7z-compressed")
         self.mime_test_mimedb("t .cb7", "application/x-7z-compressed")
         self.mime_test_mimedb("t.arj", "application/x-arj")
-        self.mime_test_mimedb("t .bz2", "application/x-bzip2")
-        self.mime_test_mimedb("t .bz3", "application/x-bzip3")
         self.mime_test_mimedb("t.cab", "application/x-cab")
         self.mime_test_mimedb("t.cbr", "application/vnd.rar")
         self.mime_test_mimedb("t.cpio", "application/x-cpio")
         self.mime_test_mimedb("t.deb", "application/x-debian-package")
-        self.mime_test_mimedb("t.gz", "application/gzip")
-        self.mime_test_mimedb("t.GZ", "application/gzip")
         self.mime_test_mimedb("t.jar", "application/java-archive")
-        self.mime_test_mimedb("t.lzma", "application/x-lzma")
+        self.mime_test_mimedb("t.txt.lzma", "application/x-lzma")
         self.mime_test_mimedb("t.txt.lz", "application/x-lzip")
         self.mime_test_mimedb("t.txt.lz4", "application/x-lz4")
-        self.mime_test_mimedb("t.lzo", "application/x-lzop")
+        self.mime_test_mimedb("t.txt.lzo", "application/x-lzop")
         self.mime_test_mimedb("t.rar", "application/vnd.rar")
         self.mime_test_mimedb("t.rpm", "application/x-rpm")
         self.mime_test_mimedb("t.tar", "application/x-tar")
@@ -265,8 +264,8 @@ class TestMime(unittest.TestCase):
         self.mime_test_mimedb("t.txt.bz2", "application/x-bzip2")
         self.mime_test_mimedb("t.txt.bz3", "application/x-bzip3")
         self.mime_test_mimedb("t.txt.zst", "application/zstd")
-        self.mime_test_mimedb("t .xz", "application/x-xz")
-        self.mime_test_mimedb("t.Z", "application/x-compress")
+        self.mime_test_mimedb("t.txt.xz", "application/x-xz")
+        self.mime_test_mimedb("t.txt.Z", "application/x-compress")
         self.mime_test_mimedb(
             "t.zip", ("application/zip", "application/x-zip-compressed")
         )
@@ -275,13 +274,13 @@ class TestMime(unittest.TestCase):
         )
         self.mime_test_mimedb("t.ace", "application/x-ace")
         self.mime_test_mimedb("t.cba", "application/x-ace")
-        self.mime_test_mimedb("t.a", "application/x-archive")
+        self.mime_test_mimedb("t.txt.a", "application/x-archive")
         self.mime_test_mimedb("t.lha", "application/x-lha")
         self.mime_test_mimedb("t.lzh", "application/x-lzh")
         self.mime_test_mimedb("t.alz", "application/x-alzip")
         self.mime_test_mimedb("t.arc", "application/x-arc")
-        self.mime_test_mimedb("t.lrz", "application/x-lrzip")
-        self.mime_test_mimedb("t.rz", "application/x-rzip")
+        self.mime_test_mimedb("t.txt.lrz", "application/x-lrzip")
+        self.mime_test_mimedb("t.txt.rz", "application/x-rzip")
         self.mime_test_mimedb("t.zoo", "application/x-zoo")
         self.mime_test_mimedb("t.dms", "application/x-dms")
         self.mime_test_mimedb("t.shar", "application/x-shar")
